@@ -33,7 +33,7 @@ class WriteApi(object):
 
                     batch = json_record_array[i:i + batch_size]
 
-                    write_batch_response: WriteBatchResponse = api_instance.write(
+                    write_batch_response: WriteBatchResponse = api_instance.post_write_id(
                         dataset_id=dataset_id,
                         json_record=batch,
                         is_async=False
